@@ -11,21 +11,21 @@ from ..helpers import get_example_dir
 
 @pytest.mark.parametrize(
     'code, sig, names, op, version', [
-        ('import math; math.cos', 'cos(x, /)', ['x'], ge, (2, 7)),
+        ('import math; math.cos', 'cos(x, /)', ['x'], ge, (3, 6)),
 
-        ('next', 'next(iterator, default=None, /)', ['iterator', 'default'], ge, (2, 7)),
+        ('next', 'next(iterator, default=None, /)', ['iterator', 'default'], ge, (3, 6)),
 
-        ('str', "str(object='', /) -> str", ['object'], ge, (2, 7)),
+        ('str', "str(object='', /) -> str", ['object'], ge, (3, 6)),
 
-        ('pow', 'pow(x, y, z=None, /) -> number', ['x', 'y', 'z'], lt, (3, 5)),
+        ('pow', 'pow(x, y, z=None, /) -> number', ['x', 'y', 'z'], lt, (3, 6)),
         ('pow', 'pow(base, exp, mod=None)', ['base', 'exp', 'mod'], ge, (3, 8)),
 
         ('bytes.partition', 'partition(self, sep, /) -> (head, sep, tail)',
-         ['self', 'sep'], lt, (3, 5)),
-        ('bytes.partition', 'partition(self, sep, /)', ['self', 'sep'], ge, (3, 5)),
+         ['self', 'sep'], lt, (3, 6)),
+        ('bytes.partition', 'partition(self, sep, /)', ['self', 'sep'], ge, (3, 6)),
 
-        ('bytes().partition', 'partition(sep, /) -> (head, sep, tail)', ['sep'], lt, (3, 5)),
-        ('bytes().partition', 'partition(sep, /)', ['sep'], ge, (3, 5)),
+        ('bytes().partition', 'partition(sep, /) -> (head, sep, tail)', ['sep'], lt, (3, 6)),
+        ('bytes().partition', 'partition(sep, /)', ['sep'], ge, (3, 6)),
     ]
 )
 def test_compiled_signature(Script, environment, code, sig, names, op, version):
@@ -175,7 +175,7 @@ def test_tree_signature(Script, environment, code, expected):
         ('no_redirect(simple)', '*args, **kwargs'),
     ]
 )
-def test_nested_signatures(Script, environment, combination, expected, skip_pre_python35):
+def test_nested_signatures(Script, environment, combination, expected):
     code = dedent('''
         def simple(a, b, *, c): ...
         def simple2(x): ...
@@ -265,7 +265,7 @@ def test_pow_signature(Script):
             x(f)('''), 'f()'],
     ]
 )
-def test_wraps_signature(Script, code, signature, skip_pre_python35):
+def test_wraps_signature(Script, code, signature):
     sigs = Script(code).get_signatures()
     assert {sig.to_string() for sig in sigs} == {signature}
 
@@ -315,7 +315,7 @@ def test_dataclass_signature(Script, skip_pre_python37, start, start_params):
         ('kwargs = dict(b=3)', 'wrapped(b, /, **kwargs)'),
     ]
 )
-def test_param_resolving_to_static(Script, stmt, expected, skip_pre_python35):
+def test_param_resolving_to_static(Script, stmt, expected):
     code = dedent('''\
         def full_redirect(func):
             def wrapped(*args, **kwargs):
@@ -340,3 +340,20 @@ def test_overload(Script, code):
     x1, x2 = Script(code, path=os.path.join(dir_, 'foo.py')).get_signatures()
     assert x1.to_string() == 'with_overload(x: int, y: int) -> float'
     assert x2.to_string() == 'with_overload(x: str, y: list) -> float'
+
+
+def test_enum(Script):
+    script = Script('''\
+        from enum import Enum
+
+        class Planet(Enum):
+            MERCURY = (3.303e+23, 2.4397e6)
+            VENUS = (4.869e+24, 6.0518e6)
+
+            def __init__(self, mass, radius):
+                self.mass = mass  # in kilograms
+                self.radius = radius  # in meters
+
+        Planet.MERCURY''')
+    completion, = script.complete()
+    assert not completion.get_signatures()
